summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/kkbdaccessextensions.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficecore/kkbdaccessextensions.h')
-rw-r--r--lib/kofficecore/kkbdaccessextensions.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/kofficecore/kkbdaccessextensions.h b/lib/kofficecore/kkbdaccessextensions.h
index 46b99b2f..2aa64c74 100644
--- a/lib/kofficecore/kkbdaccessextensions.h
+++ b/lib/kofficecore/kkbdaccessextensions.h
@@ -32,7 +32,7 @@
class KKbdAccessExtensionsPrivate;
class TQWidgetList;
-class KMainWindow;
+class TDEMainWindow;
/** KKbdAccessExtensions is an object that improves accessibility for motor impaired users
* who may not be able to easily use a mouse. It adds two new capabilities using the keyboard:
@@ -98,7 +98,7 @@ class KMainWindow;
*
* @section notes Notes
*
-* The F8, Shift+F8, and Alt+F8 keys are KShortcuts and therefore user may choose different keys in
+* The F8, Shift+F8, and Alt+F8 keys are TDEShortcuts and therefore user may choose different keys in
* the application's Configure Shortcuts dialog.
*
* @note At present, these shortcuts may not be multi-key. If user sets multi-key
@@ -114,10 +114,10 @@ class KOFFICECORE_EXPORT KKbdAccessExtensions : public TQObject
public:
/** Constructor.
* @param parent KMainWindow of the application. Required.
* @param name (optional) Name of this object.
*/
- KKbdAccessExtensions(KMainWindow* parent, const char* name = 0);
+ KKbdAccessExtensions(TDEMainWindow* parent, const char* name = 0);
/** Destructor. */
virtual ~KKbdAccessExtensions();
@@ -114,10 +114,10 @@ class KOFFICECORE_EXPORT KKbdAccessExtensions : public TQObject
public:
/** Constructor.
- * @param parent KMainWindow of the application. Required.
+ * @param parent TDEMainWindow of the application. Required.
* @param name (optional) Name of this object.
*/